@@ -1,8 +1,12 @@
 #' FitIsoGrowth class
 #' 
 #' @description 
-#' The \code{FitIsoGrowth} class contains a growth model fitted to data under
-#' static conditions. Its constructor is \code{\link{fit_isothermal_growth}}.
+#' `r lifecycle::badge("superseded")`
+#' 
+#' The class [FitIsoGrowth] has been superseded by the top-level
+#' class [GrowthFit], which provides a unified approach for growth modelling.
+#' 
+#' Still, it is still returned if the superseded [fit_isothermal_growth()] is called.
 #' 
 #' It is a subclass of list with the items:
 #'      \itemize{
@@ -10,7 +14,7 @@
 #'          \item model: name of the primary inactivation model
 #'          \item starting_point: initial value of the model parameters
 #'          \item known: fixed model parameters
-#'          \item fit: object returned by \code{\link{modFit}}
+#'          \item fit: object returned by [modFit()]
 #'          \item best_prediction: model prediction for the model fitted.
 #'          }
 #' 
@@ -20,7 +24,7 @@ NULL
 
 #' @describeIn FitIsoGrowth print of the model
 #' 
-#' @param x An instance of \code{FitIsoGrowth}.
+#' @param x An instance of `FitIsoGrowth`.
 #' @param ... ignored
 #' 
 #' @export
@@ -34,19 +38,27 @@ print.FitIsoGrowth <- function(x, ...) {
     cat("Model parameters:\n")
     print(unlist(x$best_prediction$pars))
     
+    logbase <- x$logbase_mu
+    
+    if ( abs(logbase - exp(1)) < .1 ) {
+        logbase <- "e"
+    }
+    cat("\n")
+    cat(paste0("Parameter mu defined in log-", logbase, " scale"))
+    
 }
 
 #' @describeIn FitIsoGrowth compares the fitted model against the data.
 #'
-#' @param x The object of class \code{FitIsoGrowth} to plot.
+#' @param x The object of class `FitIsoGrowth` to plot.
 #' @param y ignored
 #' @param ... ignored.
-#' @param line_col Aesthetic parameter to change the colour of the line geom in the plot, see: \code{\link{geom_line}}
-#' @param line_size Aesthetic parameter to change the thickness of the line geom in the plot, see: \code{\link{geom_line}}
-#' @param line_type Aesthetic parameter to change the type of the line geom in the plot, takes numbers (1-6) or strings ("solid") see: \code{\link{geom_line}}
-#' @param point_col Aesthetic parameter to change the colour of the point geom, see: \code{\link{geom_point}}
-#' @param point_size Aesthetic parameter to change the size of the point geom, see: \code{\link{geom_point}}
-#' @param point_shape Aesthetic parameter to change the shape of the point geom, see: \code{\link{geom_point}}
+#' @param line_col Aesthetic parameter to change the colour of the line geom in the plot, see: [geom_line()]
+#' @param line_size Aesthetic parameter to change the thickness of the line geom in the plot, see: [geom_line()]
+#' @param line_type Aesthetic parameter to change the type of the line geom in the plot, takes numbers (1-6) or strings ("solid") see: [geom_line()]
+#' @param point_col Aesthetic parameter to change the colour of the point geom, see: [geom_point()]
+#' @param point_size Aesthetic parameter to change the size of the point geom, see: [geom_point()]
+#' @param point_shape Aesthetic parameter to change the shape of the point geom, see: [geom_point()]
 #'
 #' @export
 #'
@@ -77,20 +89,23 @@ plot.FitIsoGrowth <- function(x, y=NULL, ...,
 
 #' @describeIn FitIsoGrowth statistical summary of the fit.
 #'
-#' @param object Instance of \code{FitIsoGrowth}.
+#' @param object Instance of `FitIsoGrowth`.
 #' @param ... ignored
 #'
 #' @export
 #'
 summary.FitIsoGrowth <- function(object, ...) {
     
-    summary(object$fit)
+    out <- summary(object$fit)
+    out$logbase_mu <- object$logbase_mu
     
+    out
+
 }
 
 #' @describeIn FitIsoGrowth vector of model residuals.
 #'
-#' @param object Instance of \code{FitIsoGrowth}.
+#' @param object Instance of `FitIsoGrowth`.
 #' @param ... ignored
 #'
 #' @importFrom stats residuals
@@ -103,7 +118,7 @@ residuals.FitIsoGrowth <- function(object, ...) {
 
 #' @describeIn FitIsoGrowth vector of fitted model parameters.
 #'
-#' @param object an instance of \code{FitIsoGrowth}.
+#' @param object an instance of `FitIsoGrowth`.
 #' @param ... ignored
 #'
 #' @importFrom stats coef
@@ -119,7 +134,7 @@ coef.FitIsoGrowth <- function(object, ...) {
 #' @describeIn FitIsoGrowth variance-covariance matrix of the model, estimated
 #' as 1/(0.5*Hessian)
 #'
-#' @param object an instance of \code{FitIsoGrowth}.
+#' @param object an instance of `FitIsoGrowth`.
 #' @param ... ignored
 #'
 #' @export
@@ -145,7 +160,7 @@ vcov.FitIsoGrowth <- function(object, ...) {
 
 #' @describeIn FitIsoGrowth deviance of the model.
 #'
-#' @param object an instance of \code{FitIsoGrowth}.
+#' @param object an instance of `FitIsoGrowth`.
 #' @param ... ignored
 #' 
 #' @importFrom stats deviance
@@ -160,7 +175,7 @@ deviance.FitIsoGrowth <- function(object, ...) {
 
 #' @describeIn FitIsoGrowth vector of fitted values.
 #' 
-#' @param object an instance of \code{FitIsoGrowth }.
+#' @param object an instance of `FitIsoGrowth `.
 #' @param ... ignored
 #' 
 #' @export
@@ -176,7 +191,7 @@ fitted.FitIsoGrowth <- function(object, ...) {
 #' @param object an instance of FitIsoGrowth
 #' @param ... ignored
 #' @param times numeric vector describing the time points for the prediction.
-#' If \code{NULL} (default), uses the same points as those used for fitting.
+#' If `NULL` (default), uses the same points as those used for fitting.
 #' 
 #' @export
 #' 
@@ -188,16 +203,76 @@ predict.FitIsoGrowth <- function(object, times = NULL, ...) {
         
     }
     
+    # browser()
     
-    pred <- predict_isothermal_growth(object$model,
-                                      times,
-                                      object$best_prediction$pars,
-                                      check=FALSE)
+    pars <- c(coef(object), object$known)
+    my_model <- as.list(pars)
+    my_model$model <- object$model
     
+    pred <- predict_growth(times, my_model, check = FALSE,
+                           logbase_mu = object$logbase_mu)
+    
+    
+    # pred <- predict_isothermal_growth(object$model,
+    #                                   times,
+    #                                   object$best_prediction$pars,
+    #                                   check=FALSE)
+    # 
     pred$simulation$logN
     
 }
 
+#' @describeIn FitIsoGrowth loglikelihood of the model
+#' 
+#' @param object an instance of FitIsoGrowth
+#' @param ... ignored
+#' 
+#' @export
+#' 
+logLik.FitIsoGrowth <- function(object, ...) {
+    
+    ## AIC without penalty
+    n <- nrow(object$data)
+    sigma <- sqrt(object$fit$ssr/object$fit$df.residual)
+    
+    lL <- - n/2*log(2*pi) -n/2 * log(sigma^2) - 1/2/sigma^2*object$fit$ssr
+    
+    lL
+    
+}
+
+#' @describeIn FitIsoGrowth Akaike Information Criterion
+#'
+#' @param object an instance of FitIsoGrowth
+#' @param ... ignored
+#' @param k penalty for the parameters (k=2 by default)
+#' 
+#' @importFrom stats logLik
+#'
+#' @export
+#'
+AIC.FitIsoGrowth <- function(object, ..., k=2) {
+
+    ## Normal AIC
+    
+    p <- length(coef(object))
+    
+    lL <- logLik(object) 
+    
+    AIC <- 2*p - 2*lL
+
+    ## Calculate the penalty
+    
+    n <- nrow(object$data)
+
+    penalty <- (k*p^2 + k*p)/(n - p - 1)
+
+    ## Return
+
+    AIC + penalty
+
+}
+
 
 
 
